@@ -46,18 +46,18 @@ char put_tty_line( const char *s, int len, const int gflags )
       if( ++col > window_columns() ) { col = 1; fputs( "\\\n", stdout ); }
       if( ch >= 32 && ch <= 126 && ch != '\\' ) putchar( ch );
       else
-	{
-	char *cp = strchr( escapes, ch );
-	++col; putchar('\\');
-	if( cp ) putchar( escchars[cp-escapes] );
-	else
-	  {
-	  col += 2;
-	  putchar( ( ( ch >> 6 ) & 7 ) + '0' );
-	  putchar( ( ( ch >> 3 ) & 7 ) + '0' );
-	  putchar( ( ch & 7 ) + '0' );
-	  }
-	}
+        {
+        char *cp = strchr( escapes, ch );
+        ++col; putchar('\\');
+        if( cp ) putchar( escchars[cp-escapes] );
+        else
+          {
+          col += 2;
+          putchar( ( ( ch >> 6 ) & 7 ) + '0' );
+          putchar( ( ( ch >> 3 ) & 7 ) + '0' );
+          putchar( ( ch & 7 ) + '0' );
+          }
+        }
       }
     }
   if( !traditional() && ( gflags & GLS ) ) putchar('$');
@@ -98,6 +98,7 @@ const char *get_extended_line( const char *ibufp2, int *lenp, const char nonl )
   {
   static char *cvbuf = 0;	/* buffer */
   static int cvbufsz = 0;	/* buffer size */
+  void * alias;
   const char *t = ibufp2;
   int len;
 
@@ -105,7 +106,9 @@ const char *get_extended_line( const char *ibufp2, int *lenp, const char nonl )
   if( ( len = t - ibufp2 ) < 2 || !trailing_escape( ibufp2, ibufp2 + len - 1 ) )
     { if( lenp ) *lenp = len; return ibufp2; }
   if( lenp ) *lenp = -1;
-  if( !resize_buffer( (void *)&cvbuf, &cvbufsz, len ) ) return 0;
+  alias = cvbuf;
+  if( !resize_buffer( &alias, &cvbufsz, len ) ) return 0;
+  cvbuf = (char *)alias;
   memcpy( cvbuf, ibufp2, len );
   --len; cvbuf[len-1] = '\n';		/* strip trailing esc */
   if( nonl ) --len;			/* strip newline */
@@ -115,14 +118,18 @@ const char *get_extended_line( const char *ibufp2, int *lenp, const char nonl )
     if( !( ibufp2 = get_tty_line( &len2 ) ) ) return 0;
     if( len2 == 0 || ibufp2[len2-1] != '\n' )
       { set_error_msg( "Unexpected end-of-file" ); return 0; }
-    if( !resize_buffer( (void *)&cvbuf, &cvbufsz, len + len2 ) ) return 0;
+    alias = cvbuf;
+    if( !resize_buffer( &alias, &cvbufsz, len + len2 ) ) return 0;
+    cvbuf = (char *)alias;
     memcpy( cvbuf + len, ibufp2, len2 );
     len += len2;
     if( len2 < 2 || !trailing_escape( cvbuf, cvbuf + len - 1 ) ) break;
     --len; cvbuf[len-1] = '\n';		/* strip trailing esc */
     if( nonl ) --len;			/* strip newline */
     }
-  if( !resize_buffer( (void *)&cvbuf, &cvbufsz, len + 1 ) ) return 0;
+  alias = cvbuf;
+  if( !resize_buffer( &alias, &cvbufsz, len + 1 ) ) return 0;
+  cvbuf = (char *)alias;
   cvbuf[len] = 0;
   if( lenp ) *lenp = len;
   return cvbuf;
@@ -156,8 +163,10 @@ const char *get_tty_line( int *lenp )
       }
     else
       {
-      if( !resize_buffer( (void *)&ibuf, &ibufsz, i + 2 ) )
+      void * alias = ibuf;
+      if( !resize_buffer( &alias, &ibufsz, i + 2 ) )
         { if( lenp ) *lenp = 0; return 0; }
+      ibuf = (char *)alias;
       ibuf[i++] = c; if( !c ) set_binary(); if( c != '\n' ) continue;
       ibuf[i] = 0; if( lenp ) *lenp = i;
       return ibuf;
@@ -173,7 +182,9 @@ int read_stream_line( FILE *fp, char *newline_added_now )
 
   while( 1 )
     {
-    if( !resize_buffer( (void *)&sbuf, &sbufsz, i + 2 ) ) return -1;
+    void * alias = sbuf;
+    if( !resize_buffer( &alias, &sbufsz, i + 2 ) ) return -1;
+    sbuf = (char *)alias;
     c = getc( fp ); if( c == EOF ) break;
     sbuf[i++] = c;
     if( !c ) set_binary(); else if( c == '\n' ) break;
